@@ -5,7 +5,7 @@ use strict;
 no strict 'refs';
 use warnings;
 
-our $VERSION = '0.022';
+our $VERSION = '0.03';
 
 use vars qw(@ISA @EXPORT);
 our @ISA = qw(Exporter);
@@ -113,13 +113,13 @@ sub clickhouse_do {
 
 sub _select {
     my $format = shift;
-	my $param = shift;
-	my $query = shift;
-	my $cb = shift;
-	my $err_cb = shift;
+    my $param = shift;
+    my $query = shift;
+    my $cb = shift;
+    my $err_cb = shift;
 
-	$param = _init $param;
-	$param->{uri}->query_param('query' => $query);
+    $param = _init $param;
+    $param->{uri}->query_param('query' => $query);
 
     http_request
         GET => $param->{uri}->as_string(),
@@ -129,7 +129,7 @@ sub _select {
         sub {
             my $data = shift;
             my $hdr = shift;
- 		    my $status = $hdr->{Status};
+            my $status = $hdr->{Status};
 
             if ($status == 200){
                 # select ok
@@ -145,8 +145,8 @@ sub _select {
                     $err_cb->($data);
                 }
             }
-      }
-   ;
+        }
+    ;
 }
 
 sub clickhouse_select {
@@ -197,7 +197,7 @@ AnyEvent::ClickHouse - Simple but non-blocking HTTP client for ClickHouse Databa
 
 =head1 VERSION
 
-Version 0.022
+Version 0.03
 
 =head1 SYNOPSIS
 
@@ -231,6 +231,15 @@ This module implements a simple and non-blocking HTTP
 client for ClickHouse Database. It supports clickhouse_do, clickhouse_select
 clickhouse_select_array and clickhouse_select_hash methods.
 
+=head1 DEFAULTS
+
+    # connection options
+    {
+            host        => '127.0.0.1',
+            port        => 8123
+            database    => 'default'
+    }
+
 =head1 METHODS
 
 =head2 clickhouse_select
@@ -303,7 +312,7 @@ You can use URI
 =head2 clickhouse_select_array
 
 Fetch data from the table (readonly). 
-It returns a reference to an array containing a references to an arrays for each row of data fetched.
+It returns a reference to an array that contains a references to an arrays for each row of data fetched.
 
 Don't use FORMAT in query!
 
@@ -340,7 +349,8 @@ Don't use FORMAT in query!
 =head2 clickhouse_select_hash
 
 Fetch data from the table (readonly). 
-It returns a reference to an array containing a references to an hashes for each row of data fetched.
+Returns a reference to an array that contains a hashref to the names of the columns (as keys)
+and the data itself (as values).
 
 Don't use FORMAT in query!
 
@@ -358,9 +368,9 @@ Don't use FORMAT in query!
 
             # foreach my $row (@$data) {
             #     # Do something with your row
-            #     foreach my $col (@$row) {
+            #     foreach my $key (keys %{$row}){
             #         # ... Do something
-            #         print $col."\t";
+            #         print $key." = ".$row->{$key}."\t";
             #     }
             #     print "\n";
             # }
@@ -377,7 +387,8 @@ Don't use FORMAT in query!
 
 =head2 clickhouse_do
 
-Universal method for any queries inside the database, which modify data (insert data, create, alter, detach or drop table or partition).
+Universal method for any queries inside the database,
+which modify data (insert data, create, alter, detach or drop table or partition).
 
     clickhouse_do
         {
@@ -395,7 +406,7 @@ Universal method for any queries inside the database, which modify data (insert
         [2, "Hufflepuff", "a18202568975170758 46717657846"],
         [3, "Ravenclaw", "a678 2527258545746575410210547"],
         [4, "Slytherin", "a1068267496717456 878134788953"]
-    );
+    ;
 
 
 
@@ -407,6 +418,8 @@ Universal method for any queries inside the database, which modify data (insert
 
 =item * AnyEvent   L<AnyEvent>
 
+=item * AnyEvent::Log   L<AnyEvent::Log>
+
 =back
 
 =head1 AUTHOR
